@@ -485,13 +485,19 @@ main (int argc, char *argv[])
   pagedevice = strhash_init ();
   statusdict = strhash_init ();
 
+  /*
+   * Reading papersize default from /etc/papersize
+   */
+
+  /* not yet implemented */
+
   /* 
    * Read configuration files. 
    */
 
   /* Global config. */
 #define CFG_FILE_NAME "genscript.cfg"
-  if (!read_config (genscript_library, CFG_FILE_NAME))
+  if (!read_config ("/etc", CFG_FILE_NAME))
     /* Maybe we are not installed yet, let's try ".". */
     if (!read_config ("./lib", CFG_FILE_NAME))
       fatal ("couldn't open config file \"%s\": %s", CFG_FILE_NAME,
